<?php

namespace NCSU\Auth\Adapter;

use NCSU\Auth\Adapter\WrapAuthAdapter;
use NCSU\Auth\Http\Request;

/**
 * @runTestsInSeparateProcesses
 * @backupGlobals enabled
 */
class WrapAuthAdapterTest extends \PHPUnit_Framework_TestCase
{
    /** @test */
    public function it_should_return_valid_auth_result_after_user_has_authenticated()
    {
        $this->beWrapUser('cacard');

        $adapter = new WrapAuthAdapter(Request::createFromGlobals());
        $result = $adapter->authenticate();

        $this->assertInstanceOf('\NCSU\Auth\AuthResult', $result);
        $this->assertTrue($result->isValid());
        $this->assertEquals('cacard', $result->getIdentity());
    }

    /** @test */
    public function it_should_return_invalid_auth_result_when_user_is_not_authenticated()
    {
        $this->beWrapUser('');

        $adapter = new WrapAuthAdapter(Request::createFromGlobals());
        $result = $adapter->authenticate();

        $this->assertFalse($result->isValid());
    }

    /** @test */
    public function it_should_return_true_when_the_user_is_authenticated()
    {
        $this->beWrapUser('cacard');

        $adapter = new WrapAuthAdapter(Request::createFromGlobals());
        $result = $adapter->isAuthenticated();

        $this->assertTrue($result);
    }

    /** @test */
    public function it_should_return_false_when_the_user_is_not_authenticated()
    {
        $adapter = new WrapAuthAdapter(Request::createFromGlobals());
        $result = $adapter->isAuthenticated();

        $this->assertFalse($result);
    }
    private function beWrapUser($userId)
    {
        $_SERVER['WRAP_USERID'] = $userId;
    }
}

/**
 * Stub this function to return false so that `authenticate` can run.
 */
function headers_sent()
{
    return false;
}
